@@ -1,4 +1,4 @@
 """
 Copyright (c) 2008-2021 synodriver <synodriver@gmail.com>
 """
-from pyhuffman.backends.cython._hfm_cy import *
+from pyhuffman.backends.cython._hfm import *
